require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe "Seep::Fetcher" do
  before :all do
    @link = Seep::Fetcher.open( "http://linkleaf.com/test_a.html" )
    @jpg  = Seep::Fetcher.open("http://examancer.com/pictures/funny/funny-pictures-ooooooo.jpg")
    @png  = Seep::Fetcher.open("http://examancer.com/pictures/funny/cnnpoll.png")
    @gif  = Seep::Fetcher.open("http://examancer.com/pictures/funny/lassie-shreds.gif")
    @txt  = Seep::Fetcher.open("http://examancer.com/remoteip.txt")
  end

  describe "#open" do
    it "populates #size" do
      @link.size.should == 56_607
    end
    it "populates #response_headers" do
      @link.response_headers["Server"].should match(/Apache/)
    end
    it "throws exception when :max_file_size is exceeded" do
      lambda do
        Seep::Fetcher.open( @link.url, max_file_size: 25_000 )
      end.should( raise_exception(Curl::Err::WriteError) )
    end
  end

  describe "#size" do
    it "should be the same as #body.length" do
      @link.size.should == @link.body.length
    end
  end

  describe "#dest_url" do
    it "should show the url resulting from a redirect" do
      Seep::Fetcher.open("http://reddit.com").dest_url.should == "http://www.reddit.com/"
    end
  end

  describe "#content_type" do
    it "should be nil before #open is called" do
      link = Seep::Fetcher.new("http://linkleaf.com/")
      link.content_type.should be_nil
    end
    it "returns the correct type for html" do
      @link.content_type.should == "text/html"
    end
    it "returns the correct type for images" do
      @jpg.content_type.should == "image/jpeg"
      @png.content_type.should == "image/png"
      @gif.content_type.should == "image/gif"
    end
    it "returns the correct type for text" do
      @txt.content_type.should == "text/plain"
    end
  end

  describe "#ext" do
    it "should be blank when #open has not been called" do
      Seep::Fetcher.new(@link.url)
    end
    it "should give proper extensions for images" do
      @jpg.ext.should == ".jpg"
      @png.ext.should == ".png"
      @gif.ext.should == ".gif"
    end
  end
end
